@@ -25,5 +25,4 @@ def obfuscate_mailto(value, text=False):
     else:
         link_text = mail
 
-    return mark_safe('<a href="{0:s}{1:s}">{2:s}</a>'.format(
-        obfuscate_string('mailto:'), mail, link_text))
+    return mark_safe('<a href="{0:s}{1:s}">{2:s}</a>'.format(obfuscate_string('mailto:'), mail, link_text))
